@@ -2,7 +2,6 @@
 // VKy[W͉ʂ\
 $gOut['body'] = '<form method=GET action='.$_SERVER['PHP_SELF'].'>'
 . 'VKy[W<br>'
-. '<input name="title" width="20"><br>'
+. '<input name="title" size="20" maxlength="20"><br>'
 . '<input type="submit" value="쐬"><input type="hidden" name="a" value="N"></form>'
-
 ?>
\ No newline at end of file
