@@ -19,11 +19,22 @@ $MOWIKI_HR = '#000000';
 // ӏ̃^OݒB
 //  Ƃƌgтœ͂₷ȂłB
 
-$MOWIKI_LI0 = '^ ';
-$MOWIKI_LI1 = '^ ';
-$MOWIKI_LI2 = '^ ';
+$MOWIKI_LI0 = ' ';
+$MOWIKI_LI1 = ' ';
+$MOWIKI_LI2 = ' ';
 
 // LbVׂ̗̈
 srand(time());
 $MOWIKI_RAND = rand(0,1000000);
+
+// Xg\ł̍őy[W
+$MOWIKI_LIST_MAX = 20;
+
+// tɕϊ镶
+$MOWIKI_DATE = 't';
+$MOWIKI_DATE_FORMAT = 'yNmd';
+
+// ɕϊ镶
+$MOWIKI_TIME = '';
+$MOWIKI_TIME_FORMAT = 'H:i:s';
 ?>
\ No newline at end of file
